#!/bin/sh
if [ -z "${PKGROOT}" ]; then
	export PKGROOT=$(realpath ../)
	export SSLROOT=${PKGROOT}/ssl
fi

if [ "$(which jq; echo $?)" != "0" ];then
	export PATH=${PKGROOT}/bin:${PATH}
	export LD_LIBRARY_PATH=${PKGROOT}/lib
fi

CONFIG=${PKGROOT}/config.json

if [ ! -f ${PKGROOT}/config.json ]; then
	${PKGROOT}/package.sh default 1>&2
fi

cleanup()
{
	[ ! -z ${TEMPCONF} ] && sleep 1 && rm -f ${TEMPCONF}
}

send_json()
{
	printf "Content-type: application/json; charset=utf-8\r\n"
	printf "\r\n"
	jq -c '.' ${1}
	printf "\r\n"
}

send_msg()
{
	printf "Content-type: text/html\r\n"
	printf "\r\n"
	echo ${*}
	printf "\r\n"
}

get_status()
{
	jq -f /dev/stdin ${CONFIG} <<- EOF
	{
		"vivocloud": {
			"enable" : .vivocloud.enable
		}
	}
	EOF
}

set_status()
{
	read query_string
	ACTION=$(echo ${query_string} | jq -r '.vivocloud')
	TEMPCONF=$(mktemp -p /mnt/ramdisk config-XXXXXX)
	PKG_NUMBER=$(basename ${PKGROOT})
	case ${ACTION} in
		on)
			jq '.vivocloud.enable=true' ${CONFIG} > ${TEMPCONF}
			confclient -p 99 -s vadp_module_i${PKG_NUMBER}_enable=1
			confclient -p 99 -s vadp_module_i${PKG_NUMBER}_status=on
			SERVICE=start
			;;
		off)
			jq '.vivocloud.enable=false' ${CONFIG} > ${TEMPCONF}
			confclient -p 99 -s vadp_module_i${PKG_NUMBER}_enable=0
			confclient -p 99 -s vadp_module_i${PKG_NUMBER}_status=off
			SERVICE=stop
			;;
		*)
			# Unknown ACTION, set fail
			send_msg "ERROR: Unknown ACTION."
			exit -1
	esac
	[ -f ${TEMPCONF} ] && cp ${TEMPCONF} ${CONFIG}
}

trap "exit 1" INT TERM
trap cleanup EXIT

case ${REQUEST_METHOD} in
	GET)
		get_status | send_json -
		;;
	PUT)
		set_status
		get_status | send_json -
		cd ${PKGROOT}
		${PKGROOT}/package.sh ${SERVICE} 1>&2
		;;
	*)
		send_msg "ERROR: Unknown METHOD."
		;;
esac

exit 0