#!/bin/sh
#
# Copyright (c) 2018 Vivotek Inc. All rights reserved.
#
# +-----------------------------------------------------------------+
# | THIS SOFTWARE IS FURNISHED UNDER A LICENSE AND MAY ONLY BE USED |
# | AND COPIED IN ACCORDANCE WITH THE TERMS AND CONDITIONS OF SUCH  |
# | A LICENSE AND WITH THE INCLUSION OF THE THIS COPY RIGHT NOTICE. |
# | THIS SOFTWARE OR ANY OTHER COPIES OF THIS SOFTWARE MAY NOT BE   |
# | PROVIDED OR OTHERWISE MADE AVAILABLE TO ANY OTHER PERSON. THE   |
# | OWNERSHIP AND TITLE OF THIS SOFTWARE IS NOT TRANSFERRED.        |
# |                                                                 |
# | THE INFORMATION IN THIS SOFTWARE IS SUBJECT TO CHANGE WITHOUT   |
# | ANY PRIOR NOTICE AND SHOULD NOT BE CONSTRUED AS A COMMITMENT BY |
# | VIVOTEK INC.                                                    |
# +-----------------------------------------------------------------+
#
# Date: 2018-10-02 07:43:45
# Author: Jacko Chang (jacko.chang@vivotek.com)
#

# Exit immediately if a command exits with a non-zero status.
# set -e

if [ -z "$2" ]; then
	PKGROOT="$(cd "$(dirname $(readlink -f $0))" >/dev/null && pwd)"
else
	PKGROOT=$2
fi
export PKGROOT
export PATH=${PKGROOT}/bin:${PATH}

INSTALL=${PKGROOT}/bin/install.sh
SERVICE=${PKGROOT}/bin/service.sh

fatal()
{
	echo "<script language='javaScript'>document.write('${*}')</script><br>"
	exit 1
}

# Change its working directory to the root filesystem,
# to ensure that it doesn't tie up another filesystem and prevent it from being unmounted.
cd /

ACTION=$1

logger -t vadp-utils VADP package ${PKGROOT}@${ACTION}
case ${ACTION} in
	install)
		[ -e ${PKGROOT}/lib/traits/`${PKGROOT}/bin/board-trait -m` ] || fatal "Platform check code error." `${PKGROOT}/bin/board-trait -m`
		${INSTALL} install
		;;
	remove)
		${SERVICE} stop
		${INSTALL} remove
		;;
	upgrade)
		[ -e $3/lib/traits/`$3/bin/board-trait -m` ] || fatal "Platform check code error." `$3/bin/board-trait -m`
		cp -a $3/* ${PKGROOT}
		${INSTALL} install
		${SERVICE} stop
		sleep 1
		if [ ! -f ${PKGROOT}/config.json ]; then
			return
		fi
		ENABLE=$(jq -r '.vivocloud.enable' ${PKGROOT}/config.json)
		if [ "${ENABLE}" != "true" ]; then
			return
		fi
		${SERVICE} start
		;;
	restore)
		${SERVICE} stop
		rm -f ${PKGROOT}/config.json &> /dev/null
    	${PKGROOT}/bin/keyring rm ${PKGROOT}/ssl/awsiot/IoTPrivateKey.pem &> /dev/null
		rm -f ${PKGROOT}/ssl/awsiot/* &> /dev/null
		rm -f ${PKGROOT}/ssl/ring/* &> /dev/null
		${INSTALL} restore
		;;
	start)
		${PKGROOT}/init.d/drmtags start
		${PKGROOT}/init.d/ntpset.sh start
		if [ ! -f ${PKGROOT}/config.json ]; then
			return
		fi
		ENABLE=$(jq -r '.vivocloud.enable' ${PKGROOT}/config.json)
		if [ "${ENABLE}" != "true" ]; then
			return
		fi
		${SERVICE} start
		;;
	stop)
		${SERVICE} stop
		;;
	default)
		cp ${PKGROOT}/default.json ${PKGROOT}/config.json
		;;
	reload)
		${SERVICE} stop
		sleep 1
		if [ ! -f ${PKGROOT}/config.json ]; then
			return
		fi
		ENABLE=$(jq -r '.vivocloud.enable' ${PKGROOT}/config.json)
		if [ "${ENABLE}" != "true" ]; then
			return
		fi
		${SERVICE} start
		;;
	*)
		logger -t vadp-utils Unknow action. ${ACTION}
		cd - > /dev/null
		exit 1
esac

cd - > /dev/null
exit 0
